import { __decorate } from "tslib";
import { css, html, observable, ref } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { EDITED_COLUMN_FIELD } from '../grid-pro.types';
/**
 * The AG Select Editor element.
 * @public
 * @tagname %%prefix%%-select-editor
 */
export class SelectEditor extends FoundationElement {
    init(params) {
        if (!params)
            return;
        this.params = params;
        this.value = params.value;
        this.actualWidth = params.column.getActualWidth();
    }
    getGui() {
        return this;
    }
    refresh(params) {
        return true;
    }
    getValue() {
        return this.value;
    }
    isPopup() {
        return true;
    }
    afterGuiAttached() {
        this.combobox.open = true;
    }
    changeHandler(event) {
        var _a;
        this.value = (_a = event.detail) === null || _a === void 0 ? void 0 : _a.value;
    }
    isCancelBeforeStart() {
        return !!this.params.data[EDITED_COLUMN_FIELD];
    }
}
__decorate([
    observable
], SelectEditor.prototype, "params", void 0);
__decorate([
    observable
], SelectEditor.prototype, "value", void 0);
__decorate([
    observable
], SelectEditor.prototype, "actualWidth", void 0);
/**
 * The AG Select Renderer Styles.
 * @public
 */
export const agSelectEditorStyles = css ``;
/**
 * Get a Design System prefixed Select template.
 * @param designSystem - The design system prefix to use. Defaults to 'foundation'.
 * @returns A Select component template prefixed with the correct design system.
 * @public
 */
export const getSelectEditorTemplate = (designSystem = 'foundation') => html `
  <${designSystem}-combobox
    style="width: ${(x) => x.actualWidth}px"
    ${ref('combobox')}
    ?async=${(x) => x.params.async}
    @value-change=${(x, c) => x.changeHandler(c.event)}
  >
    <options-datasource
      resourceName=${(x) => x.params.allOptionsResourceName}
      value-field=${(x) => x.params.valueField}
      label-field=${(x) => x.params.labelField}
      option-element="${designSystem}-option"
      :datasourceConfig=${(x) => x.params.datasourceOptions}
      :data=${(x) => x.params.values}
      :initialSelectedValue=${(x) => x.params.value}
    ></options-datasource>
  </${designSystem}-combobox>
`;
/**
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-select-editor\>
 */
export const foundationSelectEditor = SelectEditor.compose({
    baseName: 'select-editor',
    styles: agSelectEditorStyles,
    template: getSelectEditorTemplate(),
});
