import { html, ref } from '@microsoft/fast-element';
import { gridProErrorNames } from './grid-pro.definitions';
/**
 * Get a Design System prefixed The Grid Pro template.
 * @param prefix - The design system prefix to use. Defaults to 'foundation'.
 * @returns A grid Pro template prefixed with the correct design system.
 * @public
 */
export const getGridProTemplate = (prefix = 'foundation') => html `
  <template>
    <span part="grid" class="${(x) => x.classNames}">
      <slot name="grid" ${ref('gridSlot')}></slot>
      <slot></slot>
    </span>
    <slot
        name="grid-datasource-error"
        part="grid-datasource-error"
        class="${(x) => (x.gridErrorItems.filter(({ type }) => type === gridProErrorNames.datasource).length > 0 ? '' : 'hidden')}"
      >
        <${prefix}-dialog
          class="grid-datasource-error-dialog"
          type="error"
          show-close-icon="false"
          open
        >
          <h2 slot="top" class="title">Component unavailable</h2>
          <p>
            Please refresh to reconnect.
            It is recommended that you save your data before refreshing.
            Data is not current and may be incomplete.
          </p>
          <div slot="bottom">
            <${prefix}-button
              appearance="lightweight"
              @click=${(x) => {
    var _a;
    x.hideDatasourceError();
    (_a = x.gridProDatasource) === null || _a === void 0 ? void 0 : _a.restart();
}}
            >
              Refresh
            </${prefix}-button>
          </div>
        </${prefix}-dialog>
      </slot>
  </template>
`;
/**
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-grid-pro\>
 */
export const gridProTemplate = getGridProTemplate();
